"""PyDockDNA scoring function parameters"""
default_hydrogen_extension = ".H"
default_amber_extension = ".amber"

# Energetic terms
scoring_vdw_weight = 1.0
vdw_input_file = "vdw.in"
default_max_electrostatics_cutoff = 1
default_min_electrostatics_cutoff = -1
default_vdw_cutoff = 1.0

# AMBER
amber_elec_constant = 18.2223
